C PROGRAM OPIK
C REF: VALSECCHI ET AL. 2000, CMDA 78, 83-91
C TABARE GALLARDO, JANUARY 2017
C http://www.fisica.edu.uy/~gallardo/opik
      IMPLICIT REAL*8 (A-H,J-Z)
      DIMENSION SE(10),SM(10),ra(10)
      CHARACTER*9 APE(10)
      TWOPI = 8.0D0*DATAN(1.0D0)
      CERO  = 0.0D0
      UNO   = 1.0D0
      PI=TWOPI/2.D0
C  PLANETS
      APE(1)='Mercury'
      APE(2)='Venus'
      APE(3)='Earth'
      APE(4)='Mars'
      APE(5)='Jupiter'
      APE(6)='Saturn'
      APE(7)='Uranus'
      APE(8)='Neptune'
C MEAN SEMIMAJOR AXIS
      SE(1)=  0.387099D0
      SE(2)=  0.72333D0
      SE(3)=  1.00000D0
      SE(4)=  1.52369D0
      SE(5)=  5.2028D0
      SE(6)=  9.555D0
      SE(7)= 19.225D0
      SE(8)= 30.12D0
C MASSES
      SM(1)=1.66013679D-07
      SM(2)=2.44783833D-06
      SM(3)=3.04043264D-06
      SM(4)=3.22715144D-07
      SM(5)=9.54791938D-04
      SM(6)=2.85885980D-04
      SM(7)=4.36624404D-05
      SM(8)=5.15138902D-05
C RADIUS IN KMS
      ra(1)=   2440.0d0
      ra(2)=   6052.0d0
      ra(3)=   6371.0d0
      ra(4)=   3390.0d0
      ra(5)=  69911.0d0
      ra(6)=  58232.0d0
      ra(7)=  25362.0d0
      ra(8)=  24624.0d0
      WRITE(*,*)'OPIK: CLOSE ENCOUNTERS WITH A PLANET'
      WRITE(*,*)'COLLISION PROBABILITY BY OPIK 1951 AND'
      WRITE(*,*)'EJECTION PROBABILITY BY VALSECCHI ET AL 2000'
      WRITE(*,*)'www.fisica.edu.uy/~gallardo/opik'
      WRITE(*,*)' '
  76  WRITE(*,*)'PLANET? (Mer=1,...,Nep=8)'
      READ(*,*) INPLA
      IF(INPLA.GT.8) THEN
        WRITE(*,*)'PLANET MUST BE BETWEEN 1 AND 8'
        GOTO 76
      ENDIF
  77  WRITE(*,*)' '
      WRITE(*,*)'a(au), e, mutual inc(degrees)'
      WRITE(*,*)'example: 1.33,0.26,1.09'
      READ(*,*) ACOM,ECOM,COMINC
      IF(ACOM.LT.CERO) THEN
        WRITE(*,*)'a must be > 0'
        GOTO 77
      ENDIF
      IF(ECOM.LT.CERO.OR.ECOM.GT.1.0) THEN
        WRITE(*,*)'e must be 0 < e < 1'
        GOTO 77
      ENDIF
      IF (COMINC.LE.CERO.OR.COMINC.GE.180.) THEN
        WRITE(*,*)'i must be 0 < i <180'
        GOTO 77
      ENDIF
C OBJECT SEMIMAJOR AXIS IN UNITS OF a_planet
      AA=ACOM/SE(INPLA)
C INCLINATION IN RADIANS
      RADIN=COMINC*PI/180.D0
C TISSERAND
      TIS=UNO/AA + 2.D0*DSQRT(AA*(UNO-ECOM**2))*DCOS(RADIN)
      IF (TIS.GE.3.0) THEN
        WRITE(*,*)'CLOSE ENCOUNTERS IMPOSSIBLE'
        GOTO 77
      ENDIF
C RELATIVE VELOCITY U
      U=DSQRT(3.D0-TIS)
C PLANETARY RADIUS
      RADIO=RA(INPLA)/149.6D6/SE(INPLA)
C SIGMA COLLISION
      SIGCOL=RADIO*DSQRT(UNO+2.D0*SM(INPLA)/U**2/RADIO)
C HILL RADIUS
      RHILL=(SM(INPLA)/3)**(1.D0/3.D0)
      UXSQR=2.D0-UNO/AA-AA*(UNO-ECOM**2)
      IF(UXSQR.LT.CERO) THEN
        WRITE(*,*)'CLOSE ENCOUNTERS IMPOSSIBLE'
        GOTO 77
      ENDIF
      IF(UXSQR.LT.0.001.AND.UXSQR.GT.CERO) THEN
        WRITE(*,*)'THE METHOD FAILS BECAUSE Ux IS NEAR 0'
        GOTO 77
      ENDIF
C Ux
      UX=DSQRT(UXSQR)
C FACTOR P(SIGMA)
      FACTOR=U/UX/DSIN(RADIN)/PI
C COLLISION PROBABILITY
      PROCOL=FACTOR*SIGCOL**2
C PROBABILITY OF ENCOUNTER INSIDE RHILL
      PROHILL=FACTOR*RHILL**2
C MEAN COLLISION LIFETIME
      TAUCOL=ACOM**1.5D0/PROCOL
C MEAN TIME OF ENCOUNTER INSIDE RHILL
      TAUHILL=ACOM**1.5D0/PROHILL
C ENERGY
      ENERGIA=-1.D0/2.D0/AA
C TITA
      TITA=DACOS((UNO+2.D0*ENERGIA-U**2)/2.D0/U)
C MAXIMUM GAMA (CORRESPONDING TO SIGMA COLLISION)
      GAMAX=2.D0*DATAN(SM(INPLA)/U**2/SIGCOL)
      TIMEGA=TITA-GAMAX
      TIMAGA=TITA+GAMAX
      IF(TIMEGA.LT.CERO) TIMEGA=CERO
      IF(TIMAGA.GT.PI) TIMAGA=PI
C ENERGY MAX
      EMAX=(U**2+2.D0*U*DCOS(TIMEGA)-UNO)/2.D0
C ENERGY MIN
      EMIN=(U**2+2.D0*U*DCOS(TIMAGA)-UNO)/2.D0
C A EXTREME 2
      SEM2=-UNO/2.D0/EMAX*SE(INPLA)
C A EXTREME 1
      SEM1=-UNO/2.D0/EMIN*SE(INPLA)
      WRITE(*,*)"a(au)=",ACOM
      WRITE(*,*)"e =",ECOM
      WRITE(*,*)"i =",COMINC
      WRITE(*,*)"Tisserand =",TIS
      WRITE(*,*)"relative velocity U =",U
C THE FOLLOWING DATA USSUALLY IS NOT INTERESTING
C      write(*,*)"Ux =",ux
C      write(*,*)"sig col =",sigcol
      write(*,*)"sigma col. in planetary radii =",sigcol/RADIO
C      write(*,*)"RHill =",rhill
C      write(*,*)"RHill in au =",rhill*SE(INPLA)
      write(*,*)"RHill in planetary radii =",rhill/RADIO
C      WRITE(*,*)"tita =",tita*180.d0/pi
C      write(*,*)"tita min =",timega*180.d0/pi
C      write(*,*)"tita max =",timaga*180.d0/pi
C      write(*,*)"energy min =",emin
C      write(*,*)"energy max =",emax
      WRITE(*,*)"maximum deflection angle of the planetoc velocity:"
      WRITE(*,*)"      gama max (degrees) =",GAMAX*180.D0/PI
      WRITE(*,*)"extreme changes in semimajor axis:"
C MINIMUM SEMIMAJOR AXIS THAT THE OBJECT CAN REACH
      WRITE(*,*)"      minimum a (au) =",SEM1
C MAXIMUM SEMIMAJOR AXIS THAT THE OBJECT CAN REACH
      IF(SEM2.LT.0.D0) THEN
        WRITE(*,*)"      maximum a (au) = INFINITE"
        ELSE
        WRITE(*,*)"      maximum a (au) =",SEM2
      ENDIF
      WRITE(*,*)"========COLLISION MEAN TIME (OPIK)=========="
C THE FOLLOWING DATA USSUALLY IS NOT INTERESTING
C      write(*,*)"Opik factor =",factor
C      write(*,*)"Opik factor omni =",facomni
C      write(*,*)"Opik p(col) per orbital period =",procol
C      write(*,*)"Opik p(RH) perorbital period =",prohill
C      write(*,*)"Opik t(Hill) years =",tauhill
      WRITE(*,*)"      Opik, t(col) Myrs =",TAUCOL/1.D6
      IF(UXSQR.LT.0.01.AND.UXSQR.GT.CERO) THEN
        WRITE(*,*)'Method is not very precise because Ux is near 0 ***'
      ENDIF




C IF EMAX < 0 IT CANNOT BE EJECTED
      IF(EMAX.LT.CERO) THEN
        WRITE(*,*)"the planet ",APE(INPLA),"cannot eject this object"
        WRITE(*,*)" "
        GOTO 77
      ENDIF
C IF EMAX > 0 IT CAN BE EJECTED
      IF(EMAX.GT.CERO)THEN
        WRITE(*,*)"========EJECTION MEAN TIME (VALSECCHI)======"
C PROB 0<ENERGY<EMAX ACCORDING TO VALSECCHI ET AL 2000
C BE A CIRCLE WITH R=RHILL CENTERED IN THE PLANET INSIDE THE PLANE
C PERPERDICULAR TO U
C PROBABILITES ARE GIVEN AS AREAS OF CIRCLES IN THAT PLANE
C BUT THEY CANNOT INTERSECT THE CIRCLE WITH R=RHILL BECAUSE
C THE 2 BODY APPROXIMATION IS NOT MORE VALID
C CONSTANT C SQUARE
        C2=(SM(INPLA)/U**2)**2
        EN1=CERO
        CC1=-UNO+6.D0*U**2-U**4
C FORMULA 43 FROM VALSECCHI ET AL. 2000
        AREA1=C2/4.D0*CC1/(EN1-ENERGIA)**2/RHILL**2
        PEYEC=AREA1*PROHILL
        TAUEYE=ACOM**1.5D0/PEYEC
        WRITE(*,*)"      Valsecchi, t(ejec) Myrs =",TAUEYE/1.D6
      ENDIF
      GOTO 77
      END

      
      



